@@ -1,5 +1,6 @@
 """ Apps file for setting core main registry app package when app is ready
 """
+
 import sys
 
 from django.apps import AppConfig
@@ -18,7 +19,9 @@ class InitApp(AppConfig):
 
         """
         if "migrate" not in sys.argv:
-            from core_main_registry_app import discover
+            from core_main_registry_app.utils.refinement import (
+                watch as refinement_watch,
+            )
 
             # Init registry
-            discover.init_registry()
+            refinement_watch.init()
