@@ -1,22 +1,36 @@
 """Url router for the REST API
 """
+
 from django.urls import re_path
 from rest_framework.urlpatterns import format_suffix_patterns
 
-import core_main_app.rest.xsl_transformation.views as xslTransformationList_view
+import core_main_app.rest.xsl_transformation.views as xslt_views
+from core_main_app.rest.blob import views as blob_views
+from core_main_app.rest.blob_processing_module import (
+    views as blob_processing_module_views,
+)
 from core_main_app.rest.data import views as data_views
 from core_main_app.rest.template import views as template_views
+from core_main_app.rest.template_html_rendering import (
+    views as template_html_rendering_views,
+)
 from core_main_app.rest.template_version_manager import (
     views as template_version_manager_views,
 )
 from core_main_app.rest.user import views as user_views
 from core_main_app.rest.views import CoreSettings
 from core_main_app.rest.workspace import views as workspace_views
+from core_main_registry_app.settings import (
+    ALLOW_MULTIPLE_SCHEMAS,
+    ENABLE_BLOB_ENDPOINTS,
+)
 from core_main_registry_app.rest.data import views as registry_data_views
 from core_main_registry_app.rest.template_version_manager import (
     views as registry_template_version_manager_views,
 )
-from core_main_registry_app.settings import ENABLE_BLOB_ENDPOINTS
+from core_main_registry_app.rest.workspace import (
+    views as workspace_registry_views,
+)
 
 urlpatterns = [
     re_path(
@@ -39,6 +53,16 @@ urlpatterns = [
         template_version_manager_views.TemplateVersion.as_view(),
         name="core_main_app_rest_template_version",
     ),
+    re_path(
+        r"^template/html_rendering/$",
+        template_html_rendering_views.TemplateHtmlRenderingList.as_view(),
+        name="core_main_app_rest_template_html_rendering",
+    ),
+    re_path(
+        r"^template/html_rendering/(?P<pk>\w+)$",
+        template_html_rendering_views.TemplateHtmlRenderingDetail.as_view(),
+        name="core_main_app_rest_template_html_rendering_detail",
+    ),
     re_path(
         r"^template/version/(?P<pk>\w+)/current/$",
         registry_template_version_manager_views.CurrentTemplateVersion.as_view(),
@@ -69,6 +93,11 @@ urlpatterns = [
         data_views.DataList.as_view(),
         name="core_main_app_rest_data_list",
     ),
+    re_path(
+        r"^data/(?P<pk>\w+)/render/$",
+        data_views.DataHtmlRender.as_view(),
+        name="core_main_app_rest_data_html_render",
+    ),
     re_path(
         r"^data/permissions/$",
         data_views.DataPermissions.as_view(),
@@ -79,11 +108,6 @@ urlpatterns = [
         data_views.DataDownload.as_view(),
         name="core_main_app_rest_data_download",
     ),
-    re_path(
-        r"^data/get-full$",
-        data_views.get_by_id_with_template_info,
-        name="core_main_app_rest_data_get_by_id_with_template_info",
-    ),
     re_path(
         r"^data/query/keyword/$",
         data_views.ExecuteLocalKeywordQueryView.as_view(),
@@ -111,12 +135,12 @@ urlpatterns = [
     ),
     re_path(
         r"^data/migration/task/(?P<task_id>[\w-]+)/progress/$",
-        data_views.get_progress,
+        data_views.GetTaskProgress.as_view(),
         name="core_main_app_rest_data_migration_task_progress",
     ),
     re_path(
         r"^data/migration/task/(?P<task_id>[\w-]+)/result/$",
-        data_views.get_result,
+        data_views.GetTaskResult.as_view(),
         name="core_main_app_rest_data_migration_task_result",
     ),
     re_path(
@@ -136,22 +160,22 @@ urlpatterns = [
     ),
     re_path(
         r"^xslt/$",
-        xslTransformationList_view.XslTransformationList.as_view(),
+        xslt_views.XslTransformationList.as_view(),
         name="core_main_app_rest_xslt",
     ),
     re_path(
         r"^xslt/transform/$",
-        xslTransformationList_view.XslTransformationTransform.as_view(),
+        xslt_views.XslTransformationTransform.as_view(),
         name="core_main_app_rest_xslt_transform",
     ),
     re_path(
         r"^xslt/(?P<pk>\w+)/$",
-        xslTransformationList_view.XslTransformationDetail.as_view(),
+        xslt_views.XslTransformationDetail.as_view(),
         name="core_main_app_rest_xslt_detail",
     ),
     re_path(
         r"^workspace/$",
-        workspace_views.WorkspaceList.as_view(),
+        workspace_registry_views.WorkspaceListRegistry.as_view(),
         name="core_main_app_rest_workspace_list",
     ),
     re_path(
@@ -264,13 +288,26 @@ urlpatterns = [
         CoreSettings.as_view(),
         name="core_main_app_rest_core_settings",
     ),
+    re_path(
+        r"^template-version-manager/(?P<pk>\w+)/disable/$",
+        template_version_manager_views.DisableTemplateVersionManager.as_view(),
+        name="core_main_app_rest_template_version_manager_disable",
+    ),
+    re_path(
+        r"^template-version-manager/(?P<pk>\w+)/restore/$",
+        template_version_manager_views.RestoreTemplateVersionManager.as_view(),
+        name="core_main_app_rest_template_version_manager_restore",
+    ),
+    re_path(
+        r"^template-version-manager/global/ordering/$",
+        template_version_manager_views.GlobalTemplateVersionManagerOrdering.as_view(),
+        name="core_main_app_rest_global_template_version_manager_ordering",
+    ),
 ]
 
 urlpatterns = format_suffix_patterns(urlpatterns)
 
 if ENABLE_BLOB_ENDPOINTS:
-    from core_main_app.rest.blob import views as blob_views
-
     urlpatterns.extend(
         [
             re_path(
@@ -308,5 +345,38 @@ if ENABLE_BLOB_ENDPOINTS:
                 blob_views.BlobChangeOwner.as_view(),
                 name="core_main_app_rest_blob_change_owner",
             ),
+            re_path(
+                r"^blob/(?P<blob_id>\w+)/run/(?P<processing_module_id>\w+)$",
+                blob_views.BlobRunProcessingModule.as_view(),
+                name="core_main_app_rest_blob_run_processing_module",
+            ),
+            re_path(
+                r"^blob-processing-module/$",
+                blob_processing_module_views.BlobProcessingModuleListView.as_view(),
+                name="core_main_app_rest_blob_processing_module_list",
+            ),
+            re_path(
+                r"^blob-processing-module/(?P<blob_processing_module_id>\w+)/$",
+                blob_processing_module_views.BlobProcessingModuleManageView.as_view(),
+                name="core_main_app_rest_blob_processing_module_manage",
+            ),
         ]
     )
+
+if ALLOW_MULTIPLE_SCHEMAS:
+    urlpatterns.insert(
+        0,
+        re_path(
+            r"^template/global/$",
+            template_version_manager_views.GlobalTemplateList.as_view(),
+            name="core_main_app_rest_global_template_list",
+        ),
+    )
+    urlpatterns.insert(
+        0,
+        re_path(
+            r"^template/user/$",
+            template_version_manager_views.UserTemplateList.as_view(),
+            name="core_main_app_rest_user_template_list",
+        ),
+    )
