@@ -1,30 +1,31 @@
 """ Url router for the core main registry app
 """
-from django.conf import settings
+
 from django.conf.urls import include
 from django.contrib.auth.decorators import login_required
 from django.urls import re_path
-from drf_yasg import openapi
-from drf_yasg.views import get_schema_view
+from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView
 
 from core_main_app.components.data import api as data_api
 from core_main_app.utils.rendering import render
-from core_main_app.views.common import views as common_views
-from core_main_app.views.user import views as user_views, ajax as user_ajax
-
-from core_main_registry_app.settings import ENABLE_BLOB_ENDPOINTS
-
-schema_view = get_schema_view(
-    openapi.Info(
-        title="REST API",
-        default_version="v1",
-    ),
+from core_main_app.utils.urls import get_auth_urls
+from core_main_app.views.common import (
+    ajax as common_ajax,
+    views as common_views,
 )
+from core_main_app.views.user import views as user_views, ajax as user_ajax
+from core_main_registry_app.settings import ENABLE_BLOB_ENDPOINTS
 
 # FIXME: Check needed URLs for registry and remove the others.
 
 urlpatterns = [
     re_path(r"^$", user_views.homepage, name="core_main_app_homepage"),
+    re_path("api/schema/", SpectacularAPIView.as_view(), name="schema"),
+    re_path(
+        "docs/api/",
+        SpectacularSwaggerView.as_view(url_name="schema"),
+        name="swagger_view",
+    ),
     re_path(
         r"^locked",
         common_views.defender_error_page,
@@ -104,32 +105,6 @@ urlpatterns = [
         user_ajax.add_group_right_to_workspace,
         name="core_main_add_group_right_to_workspace",
     ),
-    re_path(
-        r"^docs/api$",
-        schema_view.with_ui("swagger", cache_timeout=0),
-        name="swagger_view",
-    ),
-    re_path(r"^tz_detect/", include("tz_detect.urls")),
-    re_path(
-        r"^password_reset/$",
-        user_views.custom_reset_password,
-        name="password_reset",
-    ),
-    re_path(
-        r"^password_reset/done/$",
-        user_views.custom_password_reset_done,
-        name="password_reset_done",
-    ),
-    re_path(
-        r"^reset/(?P<uidb64>[0-9A-Za-z_\-]+)/(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/$",
-        user_views.custom_password_reset_confirm,
-        name="password_reset_confirm",
-    ),
-    re_path(
-        r"^reset/done/$",
-        user_views.custom_password_reset_complete,
-        name="password_reset_complete",
-    ),
     re_path(
         r"^change-data-display",
         user_ajax.change_data_display,
@@ -138,43 +113,48 @@ urlpatterns = [
     re_path(
         r"^xml-editor/data",
         login_required(
-            common_views.DataContentEditor.as_view(),
+            common_views.DataXMLEditor.as_view(),
         ),
         name="core_main_app_xml_text_editor_view",
     ),
+    re_path(
+        r"^json-editor/data",
+        login_required(
+            common_views.DataJSONEditor.as_view(),
+        ),
+        name="core_main_app_json_text_editor_view",
+    ),
+    re_path(
+        r"^set-timezone",
+        user_views.set_timezone,
+        name="core_main_set_timezone",
+    ),
+    re_path(
+        r"^template/(?P<pk>[\w-]+)/edit/$",
+        common_ajax.EditTemplateVersionManagerView.as_view(),
+        name="core_main_app_edit_template",
+    ),
 ]
 
-if settings.ENABLE_SAML2_SSO_AUTH:
-    from djangosaml2 import views as saml2_views
-
-    urlpatterns.append(re_path(r"saml2/", include("djangosaml2.urls")))
-    urlpatterns.append(
-        re_path(
-            r"^saml2/login",
-            saml2_views.LoginView.as_view(),
-            name="core_main_app_login",
-        )
-    )
-    urlpatterns.append(
-        re_path(
-            r"^saml2/logout",
-            saml2_views.LogoutInitView.as_view(),
-            name="core_main_app_logout",
-        )
-    )
-else:
-    urlpatterns.append(
-        re_path(r"^login", user_views.custom_login, name="core_main_app_login")
-    )
-    urlpatterns.append(
-        re_path(
-            r"^logout", user_views.custom_logout, name="core_main_app_logout"
-        )
-    )
+urlpatterns.extend(get_auth_urls())
 
 if ENABLE_BLOB_ENDPOINTS:
     from core_main_app.components.blob import api as blob_api
 
+    urlpatterns.append(
+        re_path(
+            r"^blob/(?P<pk>[\w-]+)/metadata",
+            login_required(common_views.ManageBlobMetadata.as_view()),
+            name="core_main_app_blob_metadata",
+        )
+    )
+    urlpatterns.append(
+        re_path(
+            r"^blob",
+            common_views.ViewBlob.as_view(),
+            name="core_main_app_blob_detail",
+        )
+    )
     urlpatterns.append(
         re_path(
             r"^assign-blob-workspace",
@@ -182,3 +162,31 @@ if ENABLE_BLOB_ENDPOINTS:
             name="core_main_assign_blob_workspace",
         )
     )
+    urlpatterns.append(
+        re_path(
+            r"^add-metadata-form",
+            user_ajax.LoadBlobMetadataForm.as_view(),
+            name="core_main_blob_metadata_form",
+        )
+    )
+    urlpatterns.append(
+        re_path(
+            r"^add-metadata-to-blob",
+            user_ajax.AddMetadataToBlob.as_view(),
+            name="core_main_blob_add_metadata",
+        )
+    )
+    urlpatterns.append(
+        re_path(
+            r"^remove-metadata-from-blob",
+            user_ajax.RemoveMetadataFromBlob.as_view(),
+            name="core_main_blob_remove_metadata",
+        )
+    )
+    urlpatterns.append(
+        re_path(
+            r"^upload-file",
+            user_ajax.UploadFile.as_view(),
+            name="core_main_upload_file",
+        )
+    )
