@@ -1,63 +1,109 @@
+""" Admin views
 """
-    Admin views
-"""
-import json
+
 import logging
 
-from django.contrib.admin.views.decorators import staff_member_required
+from django.conf import settings
+from django.contrib import messages
 from django.http.response import HttpResponseRedirect
 from django.urls import reverse
 from django.utils.html import escape as html_escape
 from django.views.generic import View
 
+from core_main_app.commons.exceptions import ModelError
 from core_main_app.components.template import api as template_api
 from core_main_app.components.template_version_manager import (
     api as template_version_manager_api,
 )
+from core_main_app.utils.json_utils import load_json_string
 from core_main_app.utils.rendering import admin_render
+from core_main_app.views.common.ajax import EditTemplateVersionManagerView
 from core_main_registry_app.components.custom_resource import (
     api as custom_resource_api,
 )
+from core_main_registry_app.components.template import (
+    api as template_registry_api,
+)
 from core_main_registry_app.views.admin.forms import UploadCustomResourcesForm
 
 logger = logging.getLogger("core_main_registry_app.views.admin.views")
 
 
-@staff_member_required
-def manage_templates(request):
-    """View that allows template management.
+class ManageTemplatesRegistryView(View):
+    """Manage Templates view."""
 
-    Args:
-        request:
+    template = "core_main_registry_app/admin/templates/list.html"
 
-    Returns:
+    def get(self, request):
+        """get request
 
-    """
-    # get all current templates
-    templates = template_version_manager_api.get_global_version_managers(
-        request=request
-    )
+        Args:
+            request:
 
-    context = {
-        "object_name": "Template",
-        "available": [
-            template for template in templates if not template.is_disabled
-        ],
-        "disabled": [
-            template for template in templates if template.is_disabled
-        ],
-    }
+        Returns:
+        """
 
-    assets = {}
-    modals = []
+        templates = template_version_manager_api.get_global_version_managers(
+            request=request
+        )
+        # get all registry current template
+        registry_template = (
+            template_registry_api.get_current_registry_template(request)
+        )
+        context = {
+            "object_name": "Template",
+            "available": [
+                template for template in templates if not template.is_disabled
+            ],
+            "disabled": [
+                template for template in templates if template.is_disabled
+            ],
+            "registry_current_template": template_version_manager_api.get_by_id(
+                registry_template.version_manager_id, request
+            ),
+            "available_template_block": "core_main_registry_app/admin/core_main_app/templates/list/available.html",
+            "MULTIPLE_SCHEMAS": settings.ALLOW_MULTIPLE_SCHEMAS,
+        }
 
-    return admin_render(
-        request,
-        "core_main_app/admin/templates/list.html",
-        assets=assets,
-        context=context,
-        modals=modals,
-    )
+        assets = {
+            "js": [
+                {
+                    "path": "core_main_app/common/js/templates/list/restore.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_main_app/common/js/templates/list/modals/disable.js",
+                    "is_raw": False,
+                },
+                EditTemplateVersionManagerView.get_modal_js_path(),
+            ],
+        }
+        if settings.ALLOW_MULTIPLE_SCHEMAS:
+            assets["js"].extend(
+                [
+                    {
+                        "path": "core_main_app/common/js/templates/sort.js",
+                        "is_raw": True,
+                    },
+                    {
+                        "path": "core_main_registry_app/admin/js/templates/sort.raw.js",
+                        "is_raw": True,
+                    },
+                ]
+            )
+
+        modals = [
+            "core_main_app/admin/templates/list/modals/disable.html",
+            EditTemplateVersionManagerView.get_modal_html_path(),
+        ]
+
+        return admin_render(
+            request,
+            self.template,
+            assets=assets,
+            context=context,
+            modals=modals,
+        )
 
 
 class UploadCustomResource(View):
@@ -88,7 +134,7 @@ class UploadCustomResource(View):
         return admin_render(request, self.template_name, context=self.context)
 
     def _save_custom_resources(self, request, template_id):
-        """Saves an XSLT.
+        """Saves a JSON Custom resource.
 
         Args:
             request: Request.
@@ -102,7 +148,7 @@ class UploadCustomResource(View):
             # get the file from the form
             upload_file = request.FILES["json_file"].read().decode("utf-8")
 
-            data = json.loads(upload_file)
+            data = load_json_string(upload_file)
             custom_resource_api.replace_custom_resources_by_template(
                 template, data
             )
@@ -121,18 +167,24 @@ class CustomRegistry(View):
     """Custom registry admin view."""
 
     def get(self, request, *args, **kwargs):
+        """Get Custom Registry configuration page
+
+        Args:
+            request:
+            *args:
+            **kwargs:
+
+        Returns:
+
+        """
         data_context_list = []
-        global_template_version_manager = (
-            template_version_manager_api.get_global_version_managers(
-                request=request
-            )
-        )
-        if len(global_template_version_manager) == 1:
-            template_version_manager = list(global_template_version_manager)[0]
+        try:
             # get the current version
-            current_template_version = template_version_manager.current
+            current_registry_template = (
+                template_registry_api.get_current_registry_template(request)
+            )
             # for each template versions
-            for version in template_version_manager.versions:
+            for version in current_registry_template.version_manager.versions:
                 # get the template
                 template = template_api.get_by_id(version, request=request)
                 # get all the template's custom resources
@@ -145,12 +197,12 @@ class CustomRegistry(View):
                         "template_name": template.display_name,
                         "count": custom_resources.count(),
                         "template_id": str(template.id),
-                        "is_current": current_template_version
+                        "is_current": current_registry_template
                         == str(template.id),
                     }
                 )
-        else:
-            logger.error("We should only have one template.")
+        except ModelError as model_error:
+            messages.add_message(request, messages.ERROR, str(model_error))
 
         modals = []
 
