@@ -1,5 +1,6 @@
 """ Unit Test Data
 """
+
 from unittest.mock import patch
 
 
@@ -7,7 +8,7 @@ from core_main_app.commons import exceptions as exceptions
 from core_main_app.components.data.models import Data
 import core_main_app.components.workspace.api as workspace_api
 from core_main_app.utils.integration_tests.integration_base_test_case import (
-    MongoIntegrationBaseTestCase,
+    IntegrationBaseTestCase,
 )
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import create_mock_request
@@ -20,7 +21,7 @@ from tests.components.data.fixtures.fixtures import DataRegistryFixtures
 fixture_data = DataRegistryFixtures()
 
 
-class TestDataGetStatus(MongoIntegrationBaseTestCase):
+class TestDataGetStatus(IntegrationBaseTestCase):
     """Test Data Get Status"""
 
     fixture = fixture_data
@@ -33,17 +34,18 @@ class TestDataGetStatus(MongoIntegrationBaseTestCase):
         # Assert
         self.assertTrue(status == DataStatus.ACTIVE)
 
-    def test_data_get_status_raise_model_exception_if_status_key_does_not_exist(
+    def test_data_get_status_returns_none_if_status_key_does_not_exist(
         self,
     ):
-        """test_data_get_status_raise_model_exception_if_status_key_does_not_exist"""
+        """test_data_get_status_returns_none_if_status_key_does_not_exist"""
 
-        # Act, Assert
-        with self.assertRaises(exceptions.ModelError):
-            data_registry_api.get_status(self.fixture.data_2)
+        # Act
+        status = data_registry_api.get_status(self.fixture.data_2)
+        # Assert
+        self.assertIsNone(status)
 
 
-class TestDataSetStatus(MongoIntegrationBaseTestCase):
+class TestDataSetStatus(IntegrationBaseTestCase):
     """Test Data Set Status"""
 
     fixture = fixture_data
@@ -85,7 +87,7 @@ class TestDataSetStatus(MongoIntegrationBaseTestCase):
             )
 
 
-class TestDataPublish(MongoIntegrationBaseTestCase):
+class TestDataPublish(IntegrationBaseTestCase):
     """Test Data Publish"""
 
     fixture = fixture_data
