@@ -1,6 +1,8 @@
 """ Tests Settings
 """
 
+import os
+
 SECRET_KEY = "fake-key"
 
 INSTALLED_APPS = [
@@ -12,7 +14,7 @@ INSTALLED_APPS = [
     "django.contrib.messages",
     "django.contrib.sites",
     # Extra apps
-    "defender",
+    "menu",
     # Local apps
     "core_main_app",
     "core_main_registry_app",
@@ -65,3 +67,21 @@ CELERYBEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
 
 MONGODB_INDEXING = False
 MONGODB_ASYNC_SAVE = False
+ENABLE_ALLAUTH = False
+ENABLE_SAML2_SSO_AUTH = False
+ALLOW_MULTIPLE_SCHEMAS = True
+
+DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"
+CUSTOM_NAME = "NMRR"
+ROOT_URLCONF = "tests.urls"
+
+
+REGISTRY_XSD_FILEPATH = os.path.join(
+    "core_main_registry_app", "xsd", "res-md.xsd"
+)
+REGISTRY_XSD_FILENAME = "res-md.xsd"
+CUSTOM_REGISTRY_FILE_PATH = os.path.join(
+    "core_main_registry_app", "json", "custom_registry.json"
+)
+
+CELERY_ALWAYS_EAGER = True
